@@ -95,7 +95,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 """
 import abc
 import builtins
@@ -152,27 +152,27 @@ class EventsRuleToStepFunction(
 
         jsii.create(EventsRuleToStepFunction, self, [scope, id, props])
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="eventsRule")
     def events_rule(self) -> aws_cdk.aws_events.Rule:
-        return jsii.get(self, "eventsRule")
+        return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="stateMachine")
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
-        return jsii.get(self, "stateMachine")
+        return typing.cast(aws_cdk.aws_stepfunctions.StateMachine, jsii.get(self, "stateMachine"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="stateMachineLogGroup")
     def state_machine_log_group(self) -> aws_cdk.aws_logs.LogGroup:
-        return jsii.get(self, "stateMachineLogGroup")
+        return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "stateMachineLogGroup"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
-        return jsii.get(self, "cloudwatchAlarms")
+        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
 
 @jsii.data_type(
@@ -225,7 +225,7 @@ class EventsRuleToStepFunctionProps:
         """
         result = self._values.get("event_rule_props")
         assert result is not None, "Required property 'event_rule_props' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_events.RuleProps, result)
 
     @builtins.property
     def state_machine_props(self) -> aws_cdk.aws_stepfunctions.StateMachineProps:
@@ -235,7 +235,7 @@ class EventsRuleToStepFunctionProps:
         """
         result = self._values.get("state_machine_props")
         assert result is not None, "Required property 'state_machine_props' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_stepfunctions.StateMachineProps, result)
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
@@ -244,7 +244,7 @@ class EventsRuleToStepFunctionProps:
         :default: - Alarms are created
         """
         result = self._values.get("create_cloud_watch_alarms")
-        return result
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
@@ -253,7 +253,7 @@ class EventsRuleToStepFunctionProps:
         :default: - Default props are used
         """
         result = self._values.get("log_group_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
